@@ -80,9 +80,8 @@ fbvclog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FAL
   nllbvclog <- function(scale1, shape1, scale2, shape2, dep) {
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvclog", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi,
-      spx$lambda, dep, scale1, shape1, scale2, shape2, dns = double(1),
-      PACKAGE = "evd")$dns
+    .C(C_nllbvclog, spx$x1, spx$x2, spx$nn, spx$n, spx$thdi,
+      spx$lambda, dep, scale1, shape1, scale2, shape2, dns = double(1))$dns
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -115,7 +114,7 @@ fbvclog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FAL
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "log")
+    u = u, nat = nat, likelihood = "censored", model = "log")
 }
 
 fbvcbilog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -123,9 +122,8 @@ fbvcbilog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = F
   nllbvcbilog <- function(scale1, shape1, scale2, shape2, alpha, beta) {
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvcbilog", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
-      alpha, beta, scale1, shape1, scale2, shape2, dns = double(1),
-      PACKAGE = "evd")$dns
+    .C(C_nllbvcbilog, spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
+      alpha, beta, scale1, shape1, scale2, shape2, dns = double(1))$dns
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -159,7 +157,7 @@ fbvcbilog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = F
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "bilog")
+    u = u, nat = nat, likelihood = "censored", model = "bilog")
 }
 
 fbvcalog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -167,9 +165,8 @@ fbvcalog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FA
     if(sym) asy2 <- asy1
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvcalog", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
-       dep, asy1, asy2, scale1, shape1, scale2, shape2, dns = double(1),
-       PACKAGE = "evd")$dns
+    .C(C_nllbvcalog, spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
+       dep, asy1, asy2, scale1, shape1, scale2, shape2, dns = double(1))$dns
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -203,7 +200,7 @@ fbvcalog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FA
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "alog")
+    u = u, nat = nat, likelihood = "censored", model = "alog")
 }
 
 fbvcneglog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -211,9 +208,8 @@ fbvcneglog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale =
   nllbvcneglog <- function(scale1, shape1, scale2, shape2, dep) {
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvcneglog", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
-      dep, scale1, shape1, scale2, shape2, dns = double(1),
-      PACKAGE = "evd")$dns
+    .C(C_nllbvcneglog, spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
+      dep, scale1, shape1, scale2, shape2, dns = double(1))$dns
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -246,7 +242,7 @@ fbvcneglog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale =
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "neglog")
+    u = u, nat = nat, likelihood = "censored", model = "neglog")
 }
 
 fbvcnegbilog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -254,9 +250,8 @@ fbvcnegbilog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale
   nllbvcnegbilog <- function(scale1, shape1, scale2, shape2, alpha, beta) {
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvcnegbilog", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
-       alpha, beta, scale1, shape1, scale2, shape2, dns = double(1),
-       PACKAGE = "evd")$dns
+    .C(C_nllbvcnegbilog, spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
+       alpha, beta, scale1, shape1, scale2, shape2, dns = double(1))$dns
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -290,7 +285,7 @@ fbvcnegbilog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "negbilog")
+    u = u, nat = nat, likelihood = "censored", model = "negbilog")
 }
 
 fbvcaneglog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -299,9 +294,8 @@ fbvcaneglog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale =
     if(sym) asy2 <- asy1
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvcaneglog", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
-       dep, asy1, asy2, scale1, shape1, scale2, shape2, dns = double(1),
-       PACKAGE = "evd")$dns
+    .C(C_nllbvcaneglog, spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
+       dep, asy1, asy2, scale1, shape1, scale2, shape2, dns = double(1))$dns
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -335,7 +329,7 @@ fbvcaneglog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale =
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "aneglog")
+    u = u, nat = nat, likelihood = "censored", model = "aneglog")
 }
 
 fbvcct <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -344,9 +338,8 @@ fbvcct <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALS
     if(sym) beta <- alpha
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvcct", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
-      alpha, beta, scale1, shape1, scale2, shape2, dns = double(1),
-      PACKAGE = "evd")$dns
+    .C(C_nllbvcct, spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
+      alpha, beta, scale1, shape1, scale2, shape2, dns = double(1))$dns
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -380,7 +373,7 @@ fbvcct <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALS
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "ct")
+    u = u, nat = nat, likelihood = "censored", model = "ct")
 }
 
 fbvchr <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -388,9 +381,8 @@ fbvchr <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALS
   nllbvchr <- function(scale1, shape1, scale2, shape2, dep) {
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvchr", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi,
-      spx$lambda, dep, scale1, shape1, scale2, shape2, dns = double(1),
-      PACKAGE = "evd")$dns
+    .C(C_nllbvchr, spx$x1, spx$x2, spx$nn, spx$n, spx$thdi,
+      spx$lambda, dep, scale1, shape1, scale2, shape2, dns = double(1))$dns
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -423,7 +415,7 @@ fbvchr <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALS
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "hr")
+    u = u, nat = nat, likelihood = "censored", model = "hr")
 }
 
 fbvcamix <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -431,9 +423,8 @@ fbvcamix <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FA
   nllbvcamix <- function(scale1, shape1, scale2, shape2, alpha, beta) {
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvcamix", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
-      alpha, beta, scale1, shape1, scale2, shape2, dns = double(1),
-      PACKAGE = "evd")$dns
+    .C(C_nllbvcamix, spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$lambda,
+      alpha, beta, scale1, shape1, scale2, shape2, dns = double(1))$dns
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -466,7 +457,7 @@ fbvcamix <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FA
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "amix")
+    u = u, nat = nat, likelihood = "censored", model = "amix")
 }
 
 ### Poisson Likelihood Fitting ###
@@ -476,9 +467,8 @@ fbvplog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FAL
   nllbvplog <- function(scale1, shape1, scale2, shape2, dep) {
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvplog", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$r1, spx$r2,
-      spx$lambda, dep, scale1, shape1, scale2, shape2, dns = double(1),
-      PACKAGE = "evd")$dns
+    .C(C_nllbvplog, spx$x1, spx$x2, spx$nn, spx$thdi, spx$r1, spx$r2,
+      spx$lambda, dep, scale1, shape1, scale2, shape2, dns = double(1))$dns
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -511,7 +501,7 @@ fbvplog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FAL
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "log")
+    u = u, nat = nat, likelihood = "poisson", model = "log")
 }
 
 fbvpneglog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -519,9 +509,9 @@ fbvpneglog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale =
   nllbvpneglog <- function(scale1, shape1, scale2, shape2, dep) {
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvpneglog", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$r1,
+    .C(C_nllbvpneglog, spx$x1, spx$x2, spx$nn, spx$thdi, spx$r1,
       spx$r2, spx$lambda, dep, scale1, shape1, scale2, shape2,
-      dns = double(1), PACKAGE = "evd")$dns    
+      dns = double(1))$dns    
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -554,7 +544,7 @@ fbvpneglog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale =
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "neglog")
+    u = u, nat = nat, likelihood = "poisson", model = "neglog")
 }
 
 fbvpct <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -563,9 +553,9 @@ fbvpct <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALS
     if(sym) beta <- alpha
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvpct", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$r1, spx$r2,
+    .C(C_nllbvpct, spx$x1, spx$x2, spx$nn, spx$thdi, spx$r1, spx$r2,
       spx$lambda, alpha, beta, scale1, shape1, scale2, shape2,
-      dns = double(1), PACKAGE = "evd")$dns
+      dns = double(1))$dns
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -599,7 +589,7 @@ fbvpct <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALS
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "ct")
+    u = u, nat = nat, likelihood = "poisson", model = "ct")
 }
 
 fbvpbilog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -607,9 +597,9 @@ fbvpbilog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = F
   nllbvpbilog <- function(scale1, shape1, scale2, shape2, alpha, beta) {
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvpbilog", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$r1,
+    .C(C_nllbvpbilog, spx$x1, spx$x2, spx$nn, spx$thdi, spx$r1,
       spx$r2, spx$lambda, alpha, beta, scale1, shape1, scale2, shape2,
-      dns = double(1), PACKAGE = "evd")$dns    
+      dns = double(1))$dns    
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -643,7 +633,7 @@ fbvpbilog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = F
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "bilog")
+    u = u, nat = nat, likelihood = "poisson", model = "bilog")
 }
 
 fbvpnegbilog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -651,9 +641,9 @@ fbvpnegbilog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale
   nllbvpnegbilog <- function(scale1, shape1, scale2, shape2, alpha, beta) {
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvpnegbilog", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$r1,
+    .C(C_nllbvpnegbilog, spx$x1, spx$x2, spx$nn, spx$thdi, spx$r1,
       spx$r2, spx$lambda, alpha, beta, scale1, shape1, scale2, shape2,
-      dns = double(1), PACKAGE = "evd")$dns 
+      dns = double(1))$dns 
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -687,7 +677,7 @@ fbvpnegbilog <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "negbilog")
+    u = u, nat = nat, likelihood = "poisson", model = "negbilog")
 }
 
 fbvphr <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALSE, std.err = TRUE, corr = FALSE, method = "BFGS", warn.inf = TRUE) {
@@ -695,9 +685,8 @@ fbvphr <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALS
   nllbvphr <- function(scale1, shape1, scale2, shape2, dep) {
     if(cshape) shape2 <- shape1
     if(cscale) scale2 <- scale1
-    .C("nllbvphr", spx$x1, spx$x2, spx$nn, spx$n, spx$thdi, spx$r1, spx$r2,
-      spx$lambda, dep, scale1, shape1, scale2, shape2, dns = double(1),
-      PACKAGE = "evd")$dns
+    .C(C_nllbvphr, spx$x1, spx$x2, spx$nn, spx$thdi, spx$r1, spx$r2,
+      spx$lambda, dep, scale1, shape1, scale2, shape2, dns = double(1))$dns
   }
   param <- c("scale1", "shape1")
   if(!cscale) param <- c(param, "scale2")
@@ -730,7 +719,7 @@ fbvphr <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALS
   cmar <- c(cscale, cshape); nat <- spx$nat
   bvpost.optim(x = x, opt = opt, nm = nm, fixed.param = fixed.param,
     std.err = std.err, corr = corr, sym = sym, cmar = cmar, method = "pot",
-    u = u, nat = nat, model = "hr")
+    u = u, nat = nat, likelihood = "poisson", model = "hr")
 }
 
 ### Method Function ###
@@ -738,6 +727,7 @@ fbvphr <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALS
 "print.bvpot" <-  function(x, digits = max(3, getOption("digits") - 3), ...) 
 {
     cat("\nCall:", deparse(x$call), "\n")
+		cat("Likelihood:", x$likelihood, "\n")
     cat("Deviance:", deviance(x), "\n")
     cat("AIC:", AIC(x), "\n")
     if(!is.null(x$dep.summary)) cat("Dependence:", x$dep.summary, "\n")
@@ -772,3 +762,4 @@ fbvphr <- function(x, u, start, ..., sym = FALSE, cshape = cscale, cscale = FALS
 }
 
 
+
